__version__ = '0.2.2'
__author__  = 'Putt Sakdhnagool <putt.sakdhnagool@nectec.or.th>'
__license__ = 'MIT'

SACCT_BEGIN_DATE = '2023-02-20T14:30:00'

DEFAULT_DISPLAY_FIELDS=[
    "account",
    "description",
    "remaining_percent",
    "allocation",
    "used",
    "remaining",
]
